alter table BPEL_ACTIVITY_INST drop constraint ACT_INST_PARENT_FK;
alter table BPEL_ACTIVITY_INST drop constraint ACT_INST_CH_FK;
alter table BPEL_ACTIVITY_INST drop constraint ACT_INST_TH_FK;
alter table BPEL_ACTIVITY_INST drop constraint ACT_INST_FH_FK;
alter table BPEL_ACTIVITY_INST drop constraint ACT_INST_EXCEPTION_FK;
alter table BPEL_ACTIVITY_INST drop constraint ACT_INST_WAIT_FK;
alter table BPEL_ACTIVITY_INST drop constraint ACT_INST_CHILD_FK;
alter table BPEL_ACTIVITY_INST drop constraint SCOPE_INST_EVT_FK;
alter table BPEL_BASE_ACTIVITY_DEF drop constraint FK90444D19F1C5FAB0;
alter table BPEL_BASE_ACTIVITY_DEF drop constraint FK90444D1982112BDD;
alter table BPEL_BASE_ACTIVITY_DEF drop constraint FK90444D19614874B5;
alter table BPEL_BASE_ACTIVITY_DEF drop constraint FK90444D19DE3B31AF;
alter table BPEL_BASE_ACTIVITY_DEF drop constraint FK90444D19D4D0807A;
alter table BPEL_BASE_ACTIVITY_DEF drop constraint SCOPE_DEF_FAULT_HANDLERS_FK;
alter table BPEL_FAULT_MSG_PART drop constraint BPEL_FAULT_MSG_PART_FK;
alter table BPEL_PROC_COMMON_CS_ drop constraint FK4FD7CF5A1E706273;
alter table BPEL_PROC_COMMON_CS_ drop constraint FK4FD7CF5AF1DBFC22;
alter table COPY_FULL_IMPL drop constraint COPY_LST_FK;
alter table CORR_DEF_ drop constraint REC_CR_DEF_LST_FK;
alter table CORR_DEF_ drop constraint IVK_CR_DEF_LST_FK;
alter table CORR_DEF_ drop constraint RP_CR_DEF_LST_FK;
alter table CORR_DEF_ drop constraint ON_EVT_CORR_FK;
alter table CORR_DEF_ drop constraint ON_MSG_CORR_FK;
alter table CS_INIT_FULL_IMPL drop constraint SCOPE_INST_CS_FK;
alter table CS_PROPERTIES_ drop constraint FK1DAAEC3D1E706273;
alter table CS_PROPERTIES_ drop constraint FK1DAAEC3D2B0757BD;
alter table ELSEIF_DEF_ drop constraint IF_ELSEIF_LST_FK;
alter table ELSEIF_DEF_ drop constraint FK4BC7A7A366DBBFD7;
alter table FRM_PRT_DEF_ drop constraint REC_FR_PT_LST_FK;
alter table FRM_PRT_DEF_ drop constraint IVK_FR_PT_LST_FK;
alter table FRM_PRT_DEF_ drop constraint ON_MSG_FRM_PRT_FK;
alter table FRM_PRT_DEF_ drop constraint ON_EVT_FRM_PRT_FK;
alter table FROM_TO_FULL drop constraint FROM_LST_FK;
alter table FROM_TO_FULL drop constraint TO_LST_FK;
alter table INVOKE_IN_MSG_PART drop constraint FK402D22A4F1CF451D;
alter table INVOKE_OUT_MSG_PART drop constraint FKD6F3446955C3FE6;
alter table NOVA_ACTIVITY drop constraint REPLY_OUT_FK;
alter table NOVA_ACTIVITY drop constraint ELSE_ACT_FK;
alter table NOVA_ACTIVITY drop constraint FOR_START_FK;
alter table NOVA_ACTIVITY drop constraint ACT_SCOPE_FK;
alter table NOVA_ACTIVITY drop constraint IF_ACT_FK;
alter table NOVA_ACTIVITY drop constraint FOR_COND_FK;
alter table NOVA_ACTIVITY drop constraint ACT_CHILD_FK;
alter table NOVA_ACTIVITY drop constraint WAIT_DLINE_FK;
alter table NOVA_ACTIVITY drop constraint ACT_TH_SCOPE_FK;
alter table NOVA_ACTIVITY drop constraint IF_COND_FK;
alter table NOVA_ACTIVITY drop constraint WAIT_DUR_FK;
alter table NOVA_ACTIVITY drop constraint FKE88EDDC25BE3B464;
alter table NOVA_ACTIVITY drop constraint ACT_JOIN_COND_FK;
alter table NOVA_ACTIVITY drop constraint FOR_FINAL_FK;
alter table NOVA_ACTIVITY drop constraint FKE88EDDC25F9F3677;
alter table NOVA_ACTIVITY drop constraint FKE88EDDC2220B15BF;
alter table NOVA_ACTIVITY drop constraint RECV_IN_MSG_FK;
alter table NOVA_ARGDESCRIPTOR drop constraint FK_OBJDESCR_ARGS;
alter table NOVA_ARGDESCRIPTOR drop constraint FK_ARGDESCR_DESCR;
alter table NOVA_ARGDESCRIPTOR drop constraint FK_OPER_ARGS;
alter table NOVA_BLOB_CHOPS drop constraint FK_BLOB_CHOP_OWN;
alter table NOVA_BPEL_EXEC drop constraint BPEL_EXEC_FOREACH_FK;
alter table NOVA_BPEL_EXEC drop constraint BPEL_EXEC_FLOW_FK;
alter table NOVA_BPEL_EXEC drop constraint BPEL_EXEC_PROC_FK;
alter table NOVA_BPEL_EXEC drop constraint BPEL_EXEC_SCOPE_FK;
alter table NOVA_BPEL_EXEC drop constraint BPEL_EXEC_INST_FK;
alter table NOVA_BPEL_EXEC drop constraint FKF01EB0C8B2F982DE;
alter table NOVA_BPEL_EXEC drop constraint BPEL_EXEC_PARENT_FK;
alter table NOVA_BPEL_PROCESS drop constraint FK3FB3AAB887A9CDF8;
alter table NOVA_BPEL_PROCESS drop constraint FK3FB3AAB8398073E8;
alter table NOVA_BPEL_PROCESS drop constraint FK3FB3AAB89A504866;
alter table NOVA_BPEL_TESTS drop constraint FK14825CAA8DCEEF2D;
alter table NOVA_BPEL_VARIABLE drop constraint FKA82FCF3381EEAE9;
alter table NOVA_BPEL_VARIABLE drop constraint FKA82FCF33BA6A18F5;
alter table NOVA_BPEL_VARIABLE drop constraint SCOPE_VAR_FK;
alter table NOVA_CLOB_CHOPS drop constraint FK_CLOB_CHOP_OWN;
alter table NOVA_COMMENT drop constraint FK_COMMENT_PARENT;
alter table NOVA_COPY_ELT drop constraint RECEIVE_IN_FK;
alter table NOVA_COPY_ELT drop constraint FK2D2E1B765C53F732;
alter table NOVA_COPY_ELT drop constraint REPLY_MSG_EX_FK;
alter table NOVA_COPY_ELT drop constraint FK2D2E1B76DE1523BD;
alter table NOVA_COPY_ELT drop constraint ASSIGN_COPY_FK;
alter table NOVA_COPY_ELT drop constraint INVOKE_IN_FK;
alter table NOVA_COPY_ELT drop constraint INVOKE_OUT_FK;
alter table NOVA_COPY_ELT drop constraint FK2D2E1B766464ED5D;
alter table NOVA_COPY_ELT drop constraint FK2D2E1B763A9909E3;
alter table NOVA_CORREL drop constraint FK7C680C66F00CA0D;
alter table NOVA_CORREL drop constraint REPLY_COR_FK;
alter table NOVA_CORREL drop constraint FK7C680C61BC92050;
alter table NOVA_CORREL drop constraint INV_RES_FK;
alter table NOVA_CORREL drop constraint RECV_COR_FK;
alter table NOVA_CORREL drop constraint FK7C680C6F7C10905;
alter table NOVA_CORREL drop constraint INV_REQ_FK;
alter table NOVA_CS drop constraint SCOPE_CS_FK;
alter table NOVA_CS_INST_PROP drop constraint CS_INST_PROP_FK;
alter table NOVA_CS_RUNTIME drop constraint FK7E7EB4DCADAF3787;
alter table NOVA_CS_RUNTIME drop constraint BPEL_SCOPE_CS_FK;
alter table NOVA_CS_RUN_PROP drop constraint FK51F62C1341321DA8;
alter table NOVA_DESCRIPTOR drop constraint FK_DESCR_KEYDESCR;
alter table NOVA_DESCRIPTOR drop constraint DESCR_ARG_REF_FK;
alter table NOVA_DESCRIPTOR drop constraint FK_DESCR_PROPS;
alter table NOVA_DESCRIPTOR drop constraint FK_DESCR_VALDESCR;
alter table NOVA_ELSE_IF drop constraint ELSIF_FK;
alter table NOVA_ELSE_IF drop constraint ELSIF_ACT_FK;
alter table NOVA_ELSE_IF drop constraint ELSIF_COND_FK;
alter table NOVA_EVENT drop constraint FK_EVENT_PROCESS;
alter table NOVA_EVENT drop constraint FK_EVENT_PROCDEF;
alter table NOVA_EVENT drop constraint FK_EVENT_TRANS;
alter table NOVA_EVENT drop constraint FK_EVENT_NODE;
alter table NOVA_EVENT drop constraint FK_EVENT_PROPS;
alter table NOVA_EXCEPTHNDLR drop constraint FK_EXHDLR_PROCESS;
alter table NOVA_EXCEPTHNDLR drop constraint FK_EXHDLR_TRANS;
alter table NOVA_EXCEPTHNDLR drop constraint FK_EXHDLR_EVENT;
alter table NOVA_EXCEPTHNDLR drop constraint FK_EXHDLR_NODE;
alter table NOVA_EXECUTION drop constraint FK_EXEC_TRANSORIG;
alter table NOVA_EXECUTION drop constraint FK_EXEC_PROCESS;
alter table NOVA_EXECUTION drop constraint FK_EXEC_INSTANCE;
alter table NOVA_EXECUTION drop constraint FKDC1376A56B99B69F;
alter table NOVA_EXECUTION drop constraint FK_EXEC_PREV_TRANS;
alter table NOVA_EXECUTION drop constraint FK_EXEC_PREV_NODE;
alter table NOVA_EXECUTION drop constraint FK_EXEC_NODE;
alter table NOVA_EXECUTION drop constraint FK_EXEC_SUPEREXEC;
alter table NOVA_EXECUTION drop constraint FK_EXEC_PARENT;
alter table NOVA_FROM_TO_ELT drop constraint FKEB0E8F6BC4132A10;
alter table NOVA_FROM_TO_ELT drop constraint FKEB0E8F6B3ADD900A;
alter table NOVA_FROM_TO_ELT drop constraint FKEB0E8F6B4D46DC95;
alter table NOVA_INST_WAITING_EXEC drop constraint BPEL_INST_WAITING_FK;
alter table NOVA_INST_WAITING_EXEC drop constraint BPEL_EXEC_WAITING_FK;
alter table NOVA_JOB drop constraint FK_JOB_CMDDESCR;
alter table NOVA_JOB drop constraint FK_JOB_PRINST;
alter table NOVA_JOB drop constraint JOB_INV_OP_KEY_FK;
alter table NOVA_JOB drop constraint FK_JOB_NODE;
alter table NOVA_JOB drop constraint FK9029010A722C9785;
alter table NOVA_JOB drop constraint FK_JOB_EXECUTION;
alter table NOVA_LINK drop constraint FLOW_LINK_FK;
alter table NOVA_LINK drop constraint FK74F7F42DC74809C5;
alter table NOVA_LINK drop constraint FK74F7F42DA26937BB;
alter table NOVA_LINK_RUNTIME drop constraint BPEL_LINK_EXEC_FK;
alter table NOVA_LINK_RUNTIME drop constraint BPEL_FLOW_LINK_FK;
alter table NOVA_NAMESPACE drop constraint FK67BDC0E8329E08E;
alter table NOVA_NODE drop constraint FK_NODES_PROCESS;
alter table NOVA_NODE drop constraint FK_NODE_PROCESS;
alter table NOVA_NODE drop constraint FK_NODE_DEFTRANS;
alter table NOVA_NODE drop constraint FK_NODE_PROPS;
alter table NOVA_NODE drop constraint FK_NODE_BEHAV_DESCR;
alter table NOVA_NODE drop constraint FK_NODE_PARENT;
alter table NOVA_OBJECTREF drop constraint FK_OBJREF_EVENT;
alter table NOVA_OBJECTREF drop constraint FK_OBJREF_EXHNDLR;
alter table NOVA_OBJECTREF drop constraint FK_OBJECTREF_EVENT;
alter table NOVA_ON_ALARM drop constraint FKEF13C684FAD5EF6D;
alter table NOVA_ON_ALARM drop constraint ACT_ON_ALARM_FK;
alter table NOVA_ON_ALARM drop constraint FKEF13C68458E1CE94;
alter table NOVA_ON_ALARM drop constraint FKEF13C68427FB7252;
alter table NOVA_ON_ALARM drop constraint PICK_ON_ALRM_FK;
alter table NOVA_ON_ALARM drop constraint FKEF13C6845C32DA50;
alter table NOVA_ON_EVT drop constraint ACT_ON_EVT_FK;
alter table NOVA_ON_EVT drop constraint FK1C384AD627FB7252;
alter table NOVA_ON_EVT drop constraint FK1C384AD65F9F3677;
alter table NOVA_ON_EVT drop constraint FK1C384AD6F7237F7A;
alter table NOVA_ON_MSG drop constraint FK1C38687427FB7252;
alter table NOVA_ON_MSG drop constraint PICK_ON_MSG_FK;
alter table NOVA_ON_MSG drop constraint FK1C3868745F9F3677;
alter table NOVA_ON_MSG drop constraint FK1C386874F7237F7A;
alter table NOVA_OPERATION drop constraint FK_OPER_PROPDESC;
alter table NOVA_OPERATION drop constraint FK_OPER_FIELDDESC;
alter table NOVA_OPERATION drop constraint FK_OPER_OBJDESCR;
alter table NOVA_PENDING_MESS drop constraint BPEL_PEND_MSG_RECV_FK;
alter table NOVA_PENDING_MSG_PART drop constraint NOVA_PENDING_MSG_PART_FK;
alter table NOVA_PLNK drop constraint SCOPE_PL_FK;
alter table NOVA_PLNKTYPE drop constraint FKD0B7022664EEA1B7;
alter table NOVA_PLNKT_ROLES drop constraint FK6B41F886A4BE5179;
alter table NOVA_PL_RUNTIME drop constraint FKD85A6A68EA5B661;
alter table NOVA_PL_RUNTIME drop constraint BPEL_SCOPE_PLK_FK;
alter table NOVA_PROCESS drop constraint FK_PROCDEF_INITIAL;
alter table NOVA_PROCESS drop constraint FK_PROCDEF_PROPS;
alter table NOVA_PROCESS_START drop constraint FK85755F7FA088E666;
alter table NOVA_PROCESS_START drop constraint FK85755F7F5F9F3677;
alter table NOVA_PROCESS_START drop constraint FK85755F7F2857DEA8;
alter table NOVA_PROPALIAS drop constraint FKF1CD045A64EEA1B7;
alter table NOVA_PROPALIAS drop constraint FKF1CD045A2E48839;
alter table NOVA_RECEIVER drop constraint BPEL_RECV_OP_KEY_FK;
alter table NOVA_RECEIVER drop constraint FK1B0ED4A22857DEA8;
alter table NOVA_REPLIER drop constraint BPEL_EXEC_REPLIERS_FK;
alter table NOVA_REPLIER drop constraint BPEL_REPKEY_OP_KEY_FK;
alter table NOVA_SCOPE_MESSEXS drop constraint SCOPE_MSG_EX_FK;
alter table NOVA_SCOPE_RUNTIME drop constraint SR_EXCEPTION_FK;
alter table NOVA_SCOPE_RUNTIME drop constraint SR_COMP_EXEC_FK;
alter table NOVA_SCOPE_RUNTIME drop constraint FKDDA191DAA36EF1E6;
alter table NOVA_SCOPE_RUNTIME drop constraint BPEL_SR_PARENT_FK;
alter table NOVA_SCOPE_VARINIT drop constraint SCOPE_INIT_VAR_FK;
alter table NOVA_SOURCE drop constraint FK2315678EDE682DBD;
alter table NOVA_SOURCE drop constraint ACT_SRC_LNK_FK;
alter table NOVA_SOURCE drop constraint FK2315678E35D1566F;
alter table NOVA_STYLESHEET drop constraint FK8FA12C41F1DBFC22;
alter table NOVA_TARGET drop constraint FK24037104DE682DBD;
alter table NOVA_TARGET drop constraint ACT_TGT_LNK_FK;
alter table NOVA_TIMERDEF drop constraint FK_TMRDEF_PROCESS;
alter table NOVA_TIMERDEF drop constraint FK_TMRDEF_NODE;
alter table NOVA_TRANSITION drop constraint FK_TRANS_PROCDEF;
alter table NOVA_TRANSITION drop constraint FK1F6E7348C9CB4133;
alter table NOVA_TRANSITION drop constraint FK1F6E7348A3459EC6;
alter table NOVA_TRANSITION drop constraint FK_TRANS_DST;
alter table NOVA_TRANSITION drop constraint FK_TRANS_SRC;
alter table NOVA_TRANSITION drop constraint FK_TRANS_PROPS;
alter table NOVA_TRANSITION drop constraint FK_TRANS_COND;
alter table NOVA_VARIABLE drop constraint FK_VAR_PROCINST;
alter table NOVA_VARIABLE drop constraint FK_VAR_EXECUTION;
alter table NOVA_VARIABLEDEF drop constraint FK_VARDEF_PROCESS;
alter table NOVA_VARIABLEDEF drop constraint FK_VARDEF_NODE;
alter table NOVA_VARIABLEDEF drop constraint FK_VARDEF_SRCDES;
alter table NOVA_VAR_MSG_PART drop constraint FKC7FCA57CAD9A96A3;
alter table NOVA_VAR_MSG_PART2 drop constraint VAR_UPD_MSG_PART_FK;
alter table NOVA_VAR_RUNTIME drop constraint FK5D0C7AED5A7F55CA;
alter table NOVA_VAR_RUNTIME drop constraint BPEL_SCOPE_VAR_FK;
alter table NOVA_WAITING_EXEC drop constraint BPEL_WAIT_EXEC_FK;
alter table NOVA_WAITING_EXEC drop constraint BPEL_WAIT_EXEC_RECV_FK;
alter table NOVA_WSDL_PROPERTY drop constraint FKCA68A07D64EEA1B7;
alter table ON_ALRM_DEF_ drop constraint PK_DF_ON_AL_FK;
alter table ON_ALRM_DEF_ drop constraint FK5B79CBB3735C61C7;
alter table ON_ALRM_DEF_ drop constraint SCOPE_DEF_ALARMS_FK;
alter table ON_EVT_DEF_ drop constraint FKC013947699EA93C4;
alter table ON_EVT_DEF_ drop constraint SCOPE_DEF_EVTS_FK;
alter table ON_MSG_DEF_ drop constraint PK_DF_ON_MSG_FK;
alter table ON_MSG_DEF_ drop constraint FK4A3B4998A6853462;
alter table PART_LNK_DEF_ drop constraint SCOPE_DEF_PL_FK;
alter table PLNK_UPDATE_FULL_IMPL drop constraint SCOPE_INST_PLNK_FK;
alter table PROCESS_INST_STATE_UPDATE_ drop constraint PROCESS_INST_STATE_FK;
alter table SCOPE_STATE_UPDATE_ drop constraint SCOPE_INST_STATE_FK;
alter table SRC_FULL_IMPL drop constraint SRC_LST_FK;
alter table TGT_FULL_IMPL drop constraint TRGT_LST_FK;
alter table TO_PRT_DEF_ drop constraint RP_TO_PT_LST_FK;
alter table TO_PRT_DEF_ drop constraint IVK_TO_PT_LST_FK;
alter table TR_COND_UPD_ drop constraint FLOW_INST_TR_COND_FK;
alter table VAR_DEF_ drop constraint SCOPE_DEF_VAR_FK;
alter table VAR_DEF_CS_ drop constraint SCOPE_DEF_CS_FK;
alter table VAR_UPDATE_FULL_IMPL drop constraint SCOPE_INST_VAR_FK;
alter table WAITING_FULL_IMPL drop constraint PICK_WAIT_FK;
alter table linkList drop constraint FLOW_LINKS_FK;
alter table messageExchanges drop constraint SCOPE_DEF_M_E_FK;
alter table properties drop constraint CORR_ST_DEF_FK;
alter table wsdlDefinitions drop constraint FKB6C7627C64EEA1B7;
drop table BPEL_ACTIVITY_INST;
drop table BPEL_BASE_ACTIVITY_DEF;
drop table BPEL_FAULT_;
drop table BPEL_FAULT_MSG_PART;
drop table BPEL_PROC_COMMON_CS_;
drop table COPY_FULL_IMPL;
drop table CORR_DEF_;
drop table CS_INIT_FULL_IMPL;
drop table CS_PROPERTIES_;
drop table ELSEIF_DEF_;
drop table FRM_PRT_DEF_;
drop table FROM_TO_FULL;
drop table INST_COUNT_;
drop table INVOKE_IN_MSG_PART;
drop table INVOKE_OUT_MSG_PART;
drop table NOVA_ACTIVITY;
drop table NOVA_ARGDESCRIPTOR;
drop table NOVA_BLOB_CHOPS;
drop table NOVA_BPEL_EXEC;
drop table NOVA_BPEL_PROCESS;
drop table NOVA_BPEL_TESTS;
drop table NOVA_BPEL_VARIABLE;
drop table NOVA_CLOB_CHOPS;
drop table NOVA_COMMENT;
drop table NOVA_COPY_ELT;
drop table NOVA_CORREL;
drop table NOVA_CS;
drop table NOVA_CS_INST_PROP;
drop table NOVA_CS_RUNTIME;
drop table NOVA_CS_RUN_PROP;
drop table NOVA_DESCRIPTOR;
drop table NOVA_ELSE_IF;
drop table NOVA_EVENT;
drop table NOVA_EXCEPTHNDLR;
drop table NOVA_EXECUTION;
drop table NOVA_FLOW_RUNTIME;
drop table NOVA_FOREACH_RUNTIME;
drop table NOVA_FROM_PART;
drop table NOVA_FROM_TO_ELT;
drop table NOVA_INST_WAITING_EXEC;
drop table NOVA_JOB;
drop table NOVA_LINK;
drop table NOVA_LINK_RUNTIME;
drop table NOVA_NAMESPACE;
drop table NOVA_NODE;
drop table NOVA_OBJECTREF;
drop table NOVA_ON_ALARM;
drop table NOVA_ON_EVT;
drop table NOVA_ON_MSG;
drop table NOVA_OPERATION;
drop table NOVA_OP_KEY;
drop table NOVA_PENDING_MESS;
drop table NOVA_PENDING_MSG_PART;
drop table NOVA_PLNK;
drop table NOVA_PLNKTYPE;
drop table NOVA_PLNKT_ROLES;
drop table NOVA_PL_RUNTIME;
drop table NOVA_PROCESS;
drop table NOVA_PROCESS_START;
drop table NOVA_PROC_COUNT;
drop table NOVA_PROPALIAS;
drop table NOVA_RECEIVER;
drop table NOVA_REPLIER;
drop table NOVA_SCOPE_MESSEXS;
drop table NOVA_SCOPE_RUNTIME;
drop table NOVA_SCOPE_VARINIT;
drop table NOVA_SNIPPET;
drop table NOVA_SOURCE;
drop table NOVA_STYLESHEET;
drop table NOVA_TARGET;
drop table NOVA_TIMERDEF;
drop table NOVA_TO_PART;
drop table NOVA_TRANSITION;
drop table NOVA_VARIABLE;
drop table NOVA_VARIABLEDEF;
drop table NOVA_VAR_MSG_PART;
drop table NOVA_VAR_MSG_PART2;
drop table NOVA_VAR_RUNTIME;
drop table NOVA_WAITING_EXEC;
drop table NOVA_WIREPROPS;
drop table NOVA_WSDLINFOS;
drop table NOVA_WSDL_PROPERTY;
drop table ON_ALRM_DEF_;
drop table ON_EVT_DEF_;
drop table ON_MSG_DEF_;
drop table PART_LNK_DEF_;
drop table PLNK_UPDATE_FULL_IMPL;
drop table PROCESS_INST_STATE_UPDATE_;
drop table SCOPE_STATE_UPDATE_;
drop table SRC_FULL_IMPL;
drop table TGT_FULL_IMPL;
drop table TO_PRT_DEF_;
drop table TR_COND_UPD_;
drop table VAR_DEF_;
drop table VAR_DEF_CS_;
drop table VAR_UPDATE_FULL_IMPL;
drop table WAITING_FULL_IMPL;
drop table linkList;
drop table messageExchanges;
drop table properties;
drop table wsdlDefinitions;
drop sequence hibernate_sequence;
